@@ -1,22 +1,24 @@
 use crate::{Padding, aes_enc, aes_dec, des_enc, des_dec};
-use aoko::no_std::functions::ext::{AnyExt1, FnOnceExt};
+use aoko::{no_std::functions::ext::{AnyExt1, FnOnceExt}, l};
 use std::fs;
 
 // ades: enc/dec file-name aes_passwd des_passwd file-name
 
 pub fn ades(r#in: String, out: String, aes: String, des: String, encrypt: bool) {
     // Read file data & Write file as partially applied function:
-    let data = fs::read(r#in).unwrap();
-    let write = |text| fs::write.partial2(text)(out).unwrap();
+    l!(
+        data = fs::read(r#in).unwrap();
+        write = |text| fs::write.partial2(text)(out).unwrap());
 
     // Initialize the remaining arguments:
     aes.padding(32).as_bytes().let_owned(|aes_key|
         des.padding(24).as_bytes().let_owned(|des_key| {
             // Crypto as partially applied function:
-            let aes_enc = |data| aes_enc(aes_key)(data);
-            let aes_dec = |data: &_| aes_dec(aes_key)(data);
-            let des_enc = |data: &_| des_enc(des_key)(data);
-            let des_dec = |data| des_dec(des_key)(data);
+            l!(
+                aes_enc = |data| aes_enc(aes_key)(data);
+                aes_dec = |data: &_| aes_dec(aes_key)(data);
+                des_enc = |data: &_| des_enc(des_key)(data);
+                des_dec = |data| des_dec(des_key)(data));
 
             // Encryption and decryption:
             match encrypt {
